@@ -35,7 +35,7 @@ our %EXPORT_TAGS = (
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT    = ( @{ $EXPORT_TAGS{'default'} } );
 
-$VERSION = '0.42';
+$VERSION = '0.45_01';
 
 {
   my %Checked;
@@ -60,21 +60,19 @@ sub _disconnect_db {
 
 sub new {
   my $package = shift;
+  my $nconf = shift if ref $_[0] and $_[0]->isa('CPANPLUS::Configure');
 
   $ENV{AUTOMATED_TESTING} = 1;
   $ENV{PERL_MM_USE_DEFAULT} = 1; # despite verbose setting
+  $ENV{PERL_EXTUTILS_AUTOINSTALL} = '--defaultdeps';
 
-  my $conf = CPANPLUS::Configure->new();
+  my $conf = $nconf || CPANPLUS::Configure->new();
 
   # Override configure settings
   $conf->set_conf( prereqs => 2 ); # force to ask callback
   $conf->set_conf( skiptest => 0 ); 
-#  unless ( ( scalar grep { -e File::Spec->catfile( $conf->get_conf('base'), $_ ) }
-#                  qw(01mailrc.txt.gz 02packages.details.txt.gz 03modlist.data.gz) ) == 3 ) {
   $conf->set_conf( no_update => 1 )
-    if glob( catfile( 
-                    $conf->get_conf('base'), 
-                    $conf->_get_source('stored') .'*'. STORABLE_EXT, ) );
+    if glob( catfile( $conf->get_conf('base'), $conf->_get_source('stored') .'*'. STORABLE_EXT, ) );
   $conf->set_conf( dist_type => 'CPANPLUS::Dist::YACSmoke' ); # this is where the magic happens.
   $conf->set_conf( cpantest => 'dont_cc' ); # Yes, we want to report test results. But not CC
   $conf->set_conf( verbose => 1 ); # set verbosity to true.
@@ -145,7 +143,7 @@ sub test {
   $self->_disconnect_db();
 
   foreach my $mod ( @mods ) {
-    eval {
+     eval {
 		CPANPLUS::Error->flush();
 		my $stat = $self->{cpanplus}->install( 
 				modules  => [ $mod ],
@@ -153,7 +151,7 @@ sub test {
 				allow_build_interactively => 0,
 				# other settings now set via set_config() method
 		);
-    };
+     };
   }
 
   $self->{cpanplus}->save_state();
